@@ -1,22 +1,19 @@
 import random
+from typing import Dict
 from datetime import datetime
 from collections import namedtuple
-from PIL import Image, ImageFilter, ImageDraw
-from PIL.Image import Image as IMG
-from typing import List, Dict, Optional
+from PIL import Image, ImageDraw, ImageFilter
 
+from nonebot_plugin_imageutils import Text2Image
 from nonebot_plugin_imageutils.fonts import Font
-from nonebot_plugin_imageutils import BuildImage, Text2Image
 
 from .utils import *
 from .depends import *
 from .download import load_image
 
-
 TEXT_TOO_LONG = "文字太长了哦，改短点再试吧~"
 NAME_TOO_LONG = "名字太长了哦，改短点再试吧~"
 REQUIRE_NAME = "找不到名字，加上名字再试吧~"
-REQUIRE_ARG = "该表情至少需要一个参数"
 
 
 def universal(img: BuildImage = UserImg(), args: List[str] = Args(0, 10)):
@@ -628,7 +625,9 @@ def my_friend(
     if not user:
         user = sender
     if not args:
-        return REQUIRE_ARG
+        args = [
+            "救命啊",
+        ]
     name = name.strip() or user.name or "朋友"
     texts = args
     img = user.img.convert("RGBA").circle().resize((100, 100))
@@ -731,7 +730,7 @@ def listen_music(img: BuildImage = UserImg(), arg=NoArg()):
 
 async def dianzhongdian(img: BuildImage = UserImg(), arg: str = Arg()):
     if not arg:
-        return REQUIRE_ARG
+        arg = "救命啊"
 
     trans = await translate(arg, lang_to="jp")
     img = img.convert("L").resize_width(500)
@@ -1386,8 +1385,9 @@ def walnut_zoom(img: BuildImage = UserImg(), arg=NoArg()):
     locs = (
         (-222, 30, 695, 430), (-212, 30, 695, 430), (0, 30, 695, 430), (41, 26, 695, 430),
         (-100, -67, 922, 570), (-172, -113, 1059, 655), (-273, -192, 1217, 753)
-    ) # (-47, -12, 801, 495), 
+    )  # (-47, -12, 801, 495),
     seq = [0, 0, 0, 1, 2, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 5, 6, 6, 6, 6]
+
     # fmt: on
 
     def maker(i: int) -> Maker:
@@ -1666,3 +1666,60 @@ def hold_tight(img: BuildImage = UserImg(), arg=NoArg()):
     frame = load_image("hold_tight/0.png")
     frame.paste(img, (113, 205), below=True)
     return frame.save_jpg()
+
+
+def look_flat(img: BuildImage = UserImg(), args: List[str] = Args(0, 2)):
+    ratio = 2
+    text = "可恶...被人看扁了"
+    for arg in args:
+        if arg.isdigit():
+            ratio = int(arg)
+            if ratio < 2 or ratio > 10:
+                ratio = 2
+        elif arg:
+            text = arg
+
+    img_w = 500
+    text_h = 80
+    text_frame = BuildImage.new("RGBA", (img_w, text_h), "white")
+    try:
+        text_frame.draw_text(
+            (10, 0, img_w - 10, text_h),
+            text,
+            max_fontsize=55,
+            min_fontsize=30,
+            weight="bold",
+        )
+    except ValueError:
+        return TEXT_TOO_LONG
+
+    def make(img: BuildImage) -> BuildImage:
+        img = img.convert("RGBA").resize_width(img_w)
+        img = img.resize((img_w, img.height // ratio))
+        img_h = img.height
+        frame = BuildImage.new("RGBA", (img_w, img_h + text_h), "white")
+        return frame.paste(img, alpha=True).paste(text_frame, (0, img_h), alpha=True)
+
+    return make_jpg_or_gif(img, make)
+
+
+def look_this_icon(img: BuildImage = UserImg(), arg: str = Arg()):
+    text = arg or "朋友\n先看看这个图标再说话"
+    frame = load_image("look_this_icon/nmsl.png")
+    try:
+        frame.draw_text(
+            (0, 933, 1170, 1143),
+            text,
+            lines_align="center",
+            weight="bold",
+            max_fontsize=100,
+            min_fontsize=50,
+        )
+    except ValueError:
+        return TEXT_TOO_LONG
+
+    def make(img: BuildImage) -> BuildImage:
+        img = img.convert("RGBA").resize((515, 515), keep_ratio=True)
+        return frame.copy().paste(img, (599, 403), below=True)
+
+    return make_jpg_or_gif(img, make)
